==> haskell-criterion-measurement-0.2.3.0-25-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-criterion-measurement.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 criterion-measurement
version:              0.2.3.0
visibility:           public
id:                   criterion-measurement-0.2.3.0-3phaEEexHq6AGf3IQ5Qp9s
key:                  criterion-measurement-0.2.3.0-3phaEEexHq6AGf3IQ5Qp9s
license:              BSD-3-Clause
copyright:            2009-2016 Bryan O'\''Sullivan and others
maintainer:
    Marco Zocca <zocca.marco gmail>, Ryan Scott <ryan.gl.scott@gmail.com>

author:               Bryan O'\''Sullivan <bos@serpentine.com>
homepage:             https://github.com/haskell/criterion
synopsis:             Criterion measurement functionality and associated types
description:
    Measurement-related functionality extracted from Criterion, with minimal dependencies. The rationale for this is to enable alternative analysis front-ends.

category:             Development, Performance, Testing, Benchmarking
abi:                  ab11031667416380820cf8ae81b98bea
exposed:              True
exposed-modules:
    Criterion.Measurement Criterion.Measurement.Types
    Criterion.Measurement.Types.Internal

import-dirs:          /usr/lib/ghc-9.4.8/site-local/criterion-measurement-0.2.3.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/criterion-measurement-0.2.3.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/criterion-measurement-0.2.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-criterion-measurement
hs-libraries:         HScriterion-measurement-0.2.3.0-3phaEEexHq6AGf3IQ5Qp9s
depends:
    aeson-2.1.2.1-LvJWrHbVhNW5j5NGQeCpIT base-4.17.2.1
    base-compat-0.13.1-8jgXJjtFto7AX0ry1QXDcA binary-0.8.9.1
    containers-0.6.7 deepseq-1.4.8.0 ghc-prim-0.9.1
    vector-0.13.2.0-7jLyylqham1Ij3AknS5IxU

haddock-interfaces:
    /usr/share/doc/haskell-criterion-measurement/html/criterion-measurement.haddock

haddock-html:         /usr/share/doc/haskell-criterion-measurement/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-criterion-measurement-0.2.3.0-26-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-criterion-measurement.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 criterion-measurement
version:              0.2.3.0
visibility:           public
id:                   criterion-measurement-0.2.3.0-3xa9xc1qmPpCj4gs7GAEdU
key:                  criterion-measurement-0.2.3.0-3xa9xc1qmPpCj4gs7GAEdU
license:              BSD-3-Clause
copyright:            2009-2016 Bryan O'\''Sullivan and others
maintainer:
    Marco Zocca <zocca.marco gmail>, Ryan Scott <ryan.gl.scott@gmail.com>

author:               Bryan O'\''Sullivan <bos@serpentine.com>
homepage:             https://github.com/haskell/criterion
synopsis:             Criterion measurement functionality and associated types
description:
    Measurement-related functionality extracted from Criterion, with minimal dependencies. The rationale for this is to enable alternative analysis front-ends.

category:             Development, Performance, Testing, Benchmarking
abi:                  ae1fc550127ee8d2016e5ee629481844
exposed:              True
exposed-modules:
    Criterion.Measurement Criterion.Measurement.Types
    Criterion.Measurement.Types.Internal

import-dirs:          /usr/lib/ghc-9.4.8/site-local/criterion-measurement-0.2.3.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/criterion-measurement-0.2.3.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/criterion-measurement-0.2.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-criterion-measurement
hs-libraries:         HScriterion-measurement-0.2.3.0-3xa9xc1qmPpCj4gs7GAEdU
depends:
    aeson-2.1.2.1-CM1TyKExMgH6p2KQqrdDHD base-4.17.2.1
    base-compat-0.13.1-8jgXJjtFto7AX0ry1QXDcA binary-0.8.9.1
    containers-0.6.7 deepseq-1.4.8.0 ghc-prim-0.9.1
    vector-0.13.2.0-LmFi28PTaN7DJJszRwFTiC

haddock-interfaces:
    /usr/share/doc/haskell-criterion-measurement/html/criterion-measurement.haddock

haddock-html:         /usr/share/doc/haskell-criterion-measurement/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
